# -*- coding: utf-8 -*- 
# @Time    : 04/13/2024 
# @Author  : nzooherd 
# @File    : video_notbuy_template.py 
# @Software: Visual Studio Code


from logging import getLogger
from typing import Dict
from template import ATag, BTag, BaseTemplate, Details, ITag, PTag, StrongTag

logger = getLogger()

class VideoNoBuyTemplate(BaseTemplate):

    def __init__(self, title, tags, preview_url, star) -> None:
        self.title = StrongTag().add(ATag(href=preview_url).value(title))
        self.star = PTag("⭐&nbsp&nbsp").add(BTag("评价星级&nbsp")).\
            add(StrongTag(self._star_value(star)))
        self.video_tags = PTag("🔖&nbsp&nbsp").add(BTag("个性标签&nbsp")).\
            add(StrongTag(self._tags_value(tags)))
        self.online_url = PTag("📹&nbsp&nbsp").add(BTag("在线观看&nbsp")).\
            add(Details().add(ITag(self._online_url())))
        self.magnet_url = PTag("🧩&nbsp&nbsp").add(BTag("下载保存&nbsp")).\
            add(Details().add(ITag(self._magnet_url())))
    
    def _star_value(self, star: int):
        assert 0 <= star <= 5, "star value error"
        value = ""
        for _ in range(star):
            value += "&nbsp&nbsp❤️"
        for _ in range(5 - star):
            value += "&nbsp&nbsp🤍"
        return value
    
    def _tags_value(self, tags: list[str]):
        return " " + " ".join("#" + tag for tag in set(tags))
    
    def _online_url(self):
        return "点击下方按钮购买后查看"
    
    def _magnet_url(self):
        return "点击下方按钮购买后查看"
    
    def hash_value(self) -> str:
        return f"{self.title}\n\n{self.star}\n\n{self.video_tags}\n\n{self.online_url}\n\n{self.magnet_url}"

    def template(self) -> Dict[int, int]:
        return {"html": self.hash_value()}


